@@ -3,7 +3,7 @@ package Markdown::Simple;
 use 5.006;
 use strict;
 use warnings;
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 use parent qw(Exporter);
 
 require XSLoader;
@@ -11,6 +11,9 @@ XSLoader::load('Markdown::Simple', $Markdown::Simple::VERSION);
 
 our @EXPORT = qw/markdown_to_html/;
 
+1;
+
+__END__
 
 =head1 NAME
 
@@ -18,7 +21,7 @@ Markdown::Simple - The great new Markdown::Simple!
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =cut
 
